@@ -3,29 +3,26 @@
 use Dancer;
 use Template;
 
+
+layout 'main';
+
 before sub {
     var note => "I ARE IN TEH BEFOR FILTERZ";
-    debug "in the before filter";
+#    request->path_info('/foo/oversee')
 };
 
 get '/foo/*' => sub {
     my ($match) = splat; # ('bar/baz')
-    debug "je suis dans /foo";
-   
+    
     use Data::Dumper;
 
-    "note: '".vars->{note}."'\n<BR>".
-    "match: $match\n<BR>".
+    "note: '".vars->{note}."'\n".
+    "match: $match\n".
     "request: ".Dumper(request);
 };
 
-# for testing Perl errors
-get '/error' => sub {
-    template();   
-};
 
 get '/' => sub {
-    debug "welcome to the home";
     template 'index', {note => vars->{note}};
 };
 
@@ -44,7 +41,6 @@ post '/new' => sub {
 };
 
 get '/say/:word' => sub {
-    content_type "text/plain";
     if (params->{word} =~ /^\d+$/) {
         pass and return false;
     }
@@ -68,4 +64,4 @@ get r('/(.*)') => sub {
     "got to trash: $trash";
 };
 
-dance;
+Dancer->dance;
